# pyfi
## 作者：wangluzhou, hupeiran
## 模块更新代码
`python setup.py register sdist upload`
## 本包功能：

致力于宏观固收领域常用功能开发，方便大家使用和学习。

分为五大模块：
1. wind_helper: wind的python接口封装
2. processing： 数据预处理功能库
3. data_agent: 指标库
4. mapper: wind代码自定义命名库
5. template: 可视化模板库,包括指标展示，回测展示
6. visual: 可视化图表库


## 相关公众号： 债圈程序猿


## 开发日志
2018-08-31 在common里面添加：get_ytm_by_net, get_dirty, get_net, get_years_to_nxcupn四个和债券相关的函数
